@@ -204,7 +204,9 @@ static void
 print_countdown_text (TimeoutDialog *timeout)
 {
         gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (timeout->dialog),
-                                                  _("The display will be reset to its previous configuration in %d seconds"),
+                                                  ngettext ("The display will be reset to its previous configuration in %d second",
+                                                            "The display will be reset to its previous configuration in %d seconds",
+                                                            timeout->countdown),
                                                   timeout->countdown);
 }
 
@@ -1344,7 +1346,7 @@ status_icon_start (GsdXrandrManager *manager)
          */
         if (!priv->status_icon) {
                 priv->status_icon = gtk_status_icon_new_from_icon_name (GSD_XRANDR_ICON_NAME);
-                gtk_status_icon_set_tooltip (priv->status_icon, _("Configure display settings"));
+                gtk_status_icon_set_tooltip_text (priv->status_icon, _("Configure display settings"));
 
                 g_signal_connect (priv->status_icon, "activate",
                                   G_CALLBACK (status_icon_activate_cb), manager);
